[libpri-commits] rmudgett: branch group/ccss r1267 - /team/group/ccss/
SVN commits to the libpri project
libpri-commits at lists.digium.com
Thu Nov 5 17:46:36 CST 2009
Author: rmudgett
Date: Thu Nov 5 17:46:32 2009
New Revision: 1267
URL: http://svnview.digium.com/svn/libpri?view=rev&rev=1267
Log:
CCSS libpri API changes.
Modified:
team/group/ccss/libpri.h
team/group/ccss/pri.c
team/group/ccss/pri_cc.c
team/group/ccss/pri_internal.h
Modified: team/group/ccss/libpri.h
URL: http://svnview.digium.com/svn/libpri/team/group/ccss/libpri.h?view=diff&rev=1267&r1=1266&r2=1267
==============================================================================
--- team/group/ccss/libpri.h (original)
+++ team/group/ccss/libpri.h Thu Nov 5 17:46:32 2009
@@ -545,12 +545,12 @@
#define PRI_SUBCMD_REROUTING 3 /*!< CallRerouting/CallDeflection received. */
#define PRI_SUBCMD_STATUS_REQ 4 /*!< Determine the status of the given party. */
#define PRI_SUBCMD_STATUS_REQ_RSP 5 /*!< Status request response */
-#define PRI_SUBCMD_CC_RECORD_RETENTION 6 /*!< Give cc_id to upper layer */
-#define PRI_SUBCMD_CC_AVAILABLE 7 /*!< Indicate that CC is available */
-#define PRI_SUBCMD_CC_REQ 8 /*!< CC activation request */
-#define PRI_SUBCMD_CC_REQ_RSP 9 /*!< CC activation request response */
-#define PRI_SUBCMD_CC_REMOTE_USER_FREE 10 /*!< Indicate that CC party B is available */
-#define PRI_SUBCMD_CC_STATUS_REQ 11 /*!< Request/prod to receive updates of CC party A status */
+#define PRI_SUBCMD_CC_AVAILABLE 6 /*!< Indicate that CC is available */
+#define PRI_SUBCMD_CC_REQ 7 /*!< CC activation request */
+#define PRI_SUBCMD_CC_REQ_RSP 8 /*!< CC activation request response */
+#define PRI_SUBCMD_CC_REMOTE_USER_FREE 9 /*!< Indicate that CC party B is available */
+#define PRI_SUBCMD_CC_STATUS_REQ 10 /*!< Request/prod to receive updates of CC party A status */
+#define PRI_SUBCMD_CC_STATUS_REQ_RSP 11 /*!< Requested update of CC party A status */
#define PRI_SUBCMD_CC_STATUS 12 /*!< Unsolicited update of CC party A status */
#define PRI_SUBCMD_CC_CALL 13 /*!< Indicate that this call is a CC callback */
#define PRI_SUBCMD_CC_CANCEL 14 /*!< Unsolicited indication that CC is canceled */
@@ -723,6 +723,7 @@
struct pri_subcmd_cc_request_rsp cc_request_rsp;
struct pri_subcmd_cc_id cc_remote_user_free;
struct pri_subcmd_cc_id cc_status_req;
+ struct pri_subcmd_cc_status cc_status_req_rsp;
struct pri_subcmd_cc_status cc_status;
struct pri_subcmd_cc_id cc_call;
struct pri_subcmd_cc_id cc_cancel;
@@ -1485,19 +1486,20 @@
*/
int pri_retrieve_rej(struct pri *ctrl, q931_call *call, int cause);
-int pri_status_request(struct pri *ctrl, int request_id, const struct pri_sr *req);
-void pri_status_request_response(struct pri *ctrl, int invoke_id, int status);
+int pri_status_req(struct pri *ctrl, int request_id, const struct pri_sr *req);
+void pri_status_req_rsp(struct pri *ctrl, int invoke_id, int status);
/* Call-completion function prototypes */
void pri_cc_available(struct pri *ctrl, q931_call *call);
-int pri_cc_request(struct pri *ctrl, long cc_id, int mode);
-void pri_cc_request_response(struct pri *ctrl, long cc_id, int status);
+int pri_cc_req(struct pri *ctrl, long cc_id, int mode);
+void pri_cc_req_rsp(struct pri *ctrl, long cc_id, int status);
void pri_cc_remote_user_free(struct pri *ctrl, long cc_id);
-int pri_cc_status_request(struct pri *ctrl, long cc_id);
+int pri_cc_status_req(struct pri *ctrl, long cc_id);
+void pri_cc_status_req_rsp(struct pri *ctrl, long cc_id, int status);
void pri_cc_status(struct pri *ctrl, long cc_id, int status);
int pri_cc_call(struct pri *ctrl, long cc_id, q931_call *call, int channel, int exclusive);
void pri_cc_cancel(struct pri *ctrl, long cc_id);
-int pri_cc_deactivate_request(struct pri *ctrl, long cc_id);
+int pri_cc_deactivate_req(struct pri *ctrl, long cc_id);
/* Get/Set PRI Timers */
#define PRI_GETSET_TIMERS
Modified: team/group/ccss/pri.c
URL: http://svnview.digium.com/svn/libpri/team/group/ccss/pri.c?view=diff&rev=1267&r1=1266&r2=1267
==============================================================================
--- team/group/ccss/pri_internal.h (original)
+++ team/group/ccss/pri_internal.h Thu Nov 5 17:46:32 2009
@@ -544,7 +544,7 @@
struct pri_cc_record {
/*! Next call-completion record in the list */
struct pri_cc_record *next;
- /*! Call-completion record id */
+ /*! Call-completion record id (0 - 65535) */
long record_id;
/*! Call-completion state */
enum CC_STATES state;
More information about the libpri-commits
mailing list
--- team/group/ccss/pri.c (original)
+++ team/group/ccss/pri.c Thu Nov 5 17:46:32 2009
@@ -905,9 +905,9 @@
* \retval 0 on success.
* \retval -1 on error.
*/
-int pri_status_request(struct pri *ctrl, int request_id, const struct pri_sr *req)
-{
- /*! \todo BUGBUG pri_status_request() not written */
+int pri_status_req(struct pri *ctrl, int request_id, const struct pri_sr *req)
+{
+ /*! \todo BUGBUG pri_status_req() not written */
return -1;
}
@@ -926,9 +926,9 @@
*
* \return Nothing
*/
-void pri_status_request_response(struct pri *ctrl, int invoke_id, int status)
-{
- /*! \todo BUGBUG pri_status_request_response() not written */
+void pri_status_req_rsp(struct pri *ctrl, int invoke_id, int status)
+{
+ /*! \todo BUGBUG pri_status_req_rsp() not written */
}
#if 0
Modified: team/group/ccss/pri_cc.c
URL: http://svnview.digium.com/svn/libpri/team/group/ccss/pri_cc.c?view=diff&rev=1267&r1=1266&r2=1267
==============================================================================
--- team/group/ccss/pri_cc.c (original)
+++ team/group/ccss/pri_cc.c Thu Nov 5 17:46:32 2009
@@ -300,7 +300,7 @@
* \retval 0 on success.
* \retval -1 on error.
*/
-int pri_cc_request(struct pri *ctrl, long cc_id, int mode)
+int pri_cc_req(struct pri *ctrl, long cc_id, int mode)
{
struct pri_sr req;
q931_call *call;
@@ -350,7 +350,7 @@
return 0;
/*! \todo BUGBUG pri_cc_request() not written */
}
/*!
@@ -363,22 +363,22 @@
*
* \return Nothing
*/
-void pri_cc_request_response(struct pri *ctrl, long cc_id, int status)
-{
- switch (ctrl->switchtype) {
- case PRI_SWITCH_QSIG:
- break;
- case PRI_SWITCH_EUROISDN_E1:
- case PRI_SWITCH_EUROISDN_T1:
- if (q931_is_ptmp(ctrl)) {
- } else {
- }
- break;
- default:
- break;
- }
-
- /*! \todo BUGBUG pri_cc_request_response() not written */
+void pri_cc_req_rsp(struct pri *ctrl, long cc_id, int status)
+{
+ switch (ctrl->switchtype) {
+ case PRI_SWITCH_QSIG:
+ break;
+ case PRI_SWITCH_EUROISDN_E1:
+ case PRI_SWITCH_EUROISDN_T1:
+ if (q931_is_ptmp(ctrl)) {
+ } else {
+ }
+ break;
+ default:
+ break;
+ }
+
+ /*! \todo BUGBUG pri_cc_req_rsp() not written */
}
/*!
@@ -414,8 +414,8 @@
* \param cc_id CC record ID to activate.
*
* \note
* There could be zero, one, or more PRI_SUBCMD_CC_STATUS responses to the
* status request depending upon how many endpoints respond to the request.
* \note
* This is expected to be called only if there are two PTMP links between
* party A and the network. (e.g., A --> * --> PSTN)
@@ -423,23 +423,54 @@
* \retval 0 on success.
* \retval -1 on error.
*/
-int pri_cc_status_request(struct pri *ctrl, long cc_id)
-{
- switch (ctrl->switchtype) {
- case PRI_SWITCH_QSIG:
- break;
- case PRI_SWITCH_EUROISDN_E1:
- case PRI_SWITCH_EUROISDN_T1:
- if (q931_is_ptmp(ctrl)) {
- } else {
- }
- break;
- default:
- break;
- }
-
- /*! \todo BUGBUG pri_cc_status_request() not written */
+int pri_cc_status_req(struct pri *ctrl, long cc_id)
+{
+ switch (ctrl->switchtype) {
+ case PRI_SWITCH_QSIG:
+ break;
+ case PRI_SWITCH_EUROISDN_E1:
+ case PRI_SWITCH_EUROISDN_T1:
+ if (q931_is_ptmp(ctrl)) {
+ } else {
+ }
+ break;
+ default:
+ break;
+ }
+
+ /*! \todo BUGBUG pri_cc_status_req() not written */
return -1;
+}
+
+/*!
+ * \brief Update the busy status of CC party A.
+ *
+ * \param ctrl D channel controller.
+ * \param cc_id CC record ID to activate.
+ * \param status Updated party A status free(0)/busy(1)
+ *
+ * \note
+ * This is expected to be called only if there are two PTMP links between
+ * party A and the network. (e.g., A --> * --> PSTN)
+ *
+ * \return Nothing
+ */
+void pri_cc_status_req_rsp(struct pri *ctrl, long cc_id, int status)
+{
+ switch (ctrl->switchtype) {
+ case PRI_SWITCH_QSIG:
+ break;
+ case PRI_SWITCH_EUROISDN_E1:
+ case PRI_SWITCH_EUROISDN_T1:
+ if (q931_is_ptmp(ctrl)) {
+ } else {
+ }
+ break;
+ default:
+ break;
+ }
+
+ /*! \todo BUGBUG pri_cc_status_req() not written */
}
/*!
@@ -543,22 +574,22 @@
* \retval 0 on success.
* \retval -1 on error.
*/
-int pri_cc_deactivate_request(struct pri *ctrl, long cc_id)
-{
- switch (ctrl->switchtype) {
- case PRI_SWITCH_QSIG:
- break;
- case PRI_SWITCH_EUROISDN_E1:
- case PRI_SWITCH_EUROISDN_T1:
- if (q931_is_ptmp(ctrl)) {
- } else {
- }
- break;
- default:
- break;
- }
-
- /*! \todo BUGBUG pri_cc_deactivate_request() not written */
+int pri_cc_deactivate_req(struct pri *ctrl, long cc_id)
+{
+ switch (ctrl->switchtype) {
+ case PRI_SWITCH_QSIG:
+ break;
+ case PRI_SWITCH_EUROISDN_E1:
+ case PRI_SWITCH_EUROISDN_T1:
+ if (q931_is_ptmp(ctrl)) {
+ } else {
+ }
+ break;
+ default:
+ break;
+ }
+
+ /*! \todo BUGBUG pri_cc_deactivate_req() not written */
return -1;
}
Modified: team/group/ccss/pri_internal.h
@@ -350,7 +350,7 @@
return 0;
- /*! \todo BUGBUG pri_cc_request() not written */
+ /*! \todo BUGBUG pri_cc_req() not written */
}
/*!
@@ -414,8 +414,8 @@
*
* \note
- * There could be zero, one, or more PRI_SUBCMD_CC_STATUS responses to the
- * status request depending upon how many endpoints respond to the request.
+ * There could be zero, one, or more PRI_SUBCMD_CC_STATUS_REQ_RSP responses to
+ * the status request depending upon how many endpoints respond to the request.
* \note
* This is expected to be called only if there are two PTMP links between
URL: http://svnview.digium.com/svn/libpri/team/group/ccss/pri_internal.h?view=diff&rev=1267&r1=1266&r2=1267
==============================================================================